==> haskell-auto-update-0.1.6-85-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-auto-update.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 auto-update
version:              0.1.6
visibility:           public
id:                   auto-update-0.1.6-CdNIZUJi4yKCjMwiAyfP2v
key:                  auto-update-0.1.6-CdNIZUJi4yKCjMwiAyfP2v
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/yesodweb/wai
synopsis:             Efficiently run periodic, on-demand actions
description:
    API docs and the README are available at <http://www.stackage.org/package/auto-update>.

category:             Control
abi:                  12296349dfd51b5f6ac81be40f4baae4
exposed:              True
exposed-modules:
    Control.AutoUpdate Control.Debounce Control.Debounce.Internal
    Control.Reaper

hidden-modules:       Control.AutoUpdate.Util
import-dirs:          /usr/lib/ghc-8.10.2/site-local/auto-update-0.1.6
library-dirs:         /usr/lib/ghc-8.10.2/site-local/auto-update-0.1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/auto-update-0.1.6
hs-libraries:         HSauto-update-0.1.6-CdNIZUJi4yKCjMwiAyfP2v
depends:              base-4.14.1.0
haddock-interfaces:   /usr/share/doc/haskell-auto-update/html/auto-update.haddock
haddock-html:         /usr/share/doc/haskell-auto-update/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-auto-update-0.1.6-87-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-auto-update.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 auto-update
version:              0.1.6
visibility:           public
id:                   auto-update-0.1.6-3jx19J8AsGd3X7FsnL44xj
key:                  auto-update-0.1.6-3jx19J8AsGd3X7FsnL44xj
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/yesodweb/wai
synopsis:             Efficiently run periodic, on-demand actions
description:
    API docs and the README are available at <http://www.stackage.org/package/auto-update>.

category:             Control
abi:                  e1cb5eb9aad961a7531270f12e193824
exposed:              True
exposed-modules:
    Control.AutoUpdate Control.Debounce Control.Debounce.Internal
    Control.Reaper

hidden-modules:       Control.AutoUpdate.Util
import-dirs:          /usr/lib/ghc-8.10.2/site-local/auto-update-0.1.6
library-dirs:         /usr/lib/ghc-8.10.2/site-local/auto-update-0.1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/auto-update-0.1.6
hs-libraries:         HSauto-update-0.1.6-3jx19J8AsGd3X7FsnL44xj
depends:              base-4.14.1.0
haddock-interfaces:   /usr/share/doc/haskell-auto-update/html/auto-update.haddock
haddock-html:         /usr/share/doc/haskell-auto-update/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
